@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.2.2;
+package Pcore::WebDriver v0.3.0;
 
 use Pcore -dist, -const, -role, -result,
   -export => {
@@ -25,8 +25,11 @@ has enable_notifications => ( is => 'ro', isa => Bool, default => 0 );
 has useragent            => ( is => 'ro', isa => Str );
 
 has proxy_type => ( is => 'ro', isa => Enum [qw[direct manual]], default => 'direct' );
-has http_proxy => ( is => 'ro', isa => Str );    # '192.168.175.1:9070'
-has ssl_proxy  => ( is => 'ro', isa => Str );    # '192.168.175.1:9070'
+has http_proxy           => ( is => 'ro', isa => Str );    # '192.168.175.1:9070'
+has ssl_proxy            => ( is => 'ro', isa => Str );    # '192.168.175.1:9070'
+has socks_proxy          => ( is => 'ro', isa => Str );    # '192.168.175.1:9050'
+has socks_proxy_username => ( is => 'ro', isa => Str );
+has socks_proxy_password => ( is => 'ro', isa => Str );
 
 has session_id => ( is => 'ro', isa => Str, init_arg => undef );
 has _proc => ( is => 'ro', isa => InstanceOf ['Pcore::Util:PM::Proc'], init_arg => undef );    # proc handle
@@ -324,9 +327,12 @@ around get_desired_capabilities => sub ( $orig, $self, $desired_capabilities = u
             takesScreenshot   => \1,
             handlesAlerts     => \1,
             proxy             => {
-                proxyType => $self->proxy_type,
-                httpProxy => $self->http_proxy,
-                sslProxy  => $self->ssl_proxy,
+                proxyType     => $self->proxy_type,
+                httpProxy     => $self->http_proxy,
+                sslProxy      => $self->ssl_proxy,
+                socksProxy    => $self->socks_proxy,
+                socksUsername => $self->socks_proxy_username,
+                socksPassword => $self->socks_proxy_password,
             },
         },
     );
@@ -1015,15 +1021,15 @@ JS
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 161, 200, 239        | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
+## |    3 | 164, 203, 242        | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 271, 352             | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
+## |    3 | 274, 358             | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 349                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 355                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 700, 706, 712, 718,  | ControlStructures::ProhibitYadaOperator - yada operator (...) used                                             |
-## |      | 724, 733, 739, 745,  |                                                                                                                |
-## |      | 751                  |                                                                                                                |
+## |    3 | 706, 712, 718, 724,  | ControlStructures::ProhibitYadaOperator - yada operator (...) used                                             |
+## |      | 730, 739, 745, 751,  |                                                                                                                |
+## |      | 757                  |                                                                                                                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
